"""..."""
from typing import List

from aligo.core import *
from aligo.response import *


class Duplicate(Core):
    """..."""

    def duplicate_list(self, drive_id: str = None) -> List[DuplicateItem]:
        """..."""
        return list(self._core_duplicate_list(drive_id))



"""..."""
from dataclasses import dataclass, field

from aligo.types import *


@dataclass
class CopyFileResponse(DataClass):
    """..."""
    file_id: str = None
    drive_id: str = None
    domain_id: str = field(default=None, repr=False)
    async_task_id: str = field(default=None, repr=False)
